@@ -1,10 +1,10 @@
 context("datasets")
 
 datashapetests = function(df, ncols, nrows, uniquecol = NULL, nuniques = NULL) {
-  expect_equal(ncol(df), ncols)
-  expect_equal(nrow(df), nrows)
+  testthat::expect_equal(ncol(df), ncols)
+  testthat::expect_equal(nrow(df), nrows)
   if (!is.null(uniquecol)) {
-    expect_equal(nrow(unique(df[uniquecol])), nuniques)
+    testthat::expect_equal(nrow(unique(df[uniquecol])), nuniques)
   }
 }
 
